@@ -153,7 +153,7 @@ setMethod(
 
       args <- append(
         list(x = x, after = after, before = before, userTags = userTags,
-             fun = fun, cacheId = cacheId, sorted = FALSE),
+             fun = fun, cacheId = cacheId, sorted = FALSE, verbose = verbose),
         list(...)
       )
 
@@ -168,7 +168,7 @@ setMethod(
     # browser(expr = exists("rrrr"))
     # if (useDBI()) {
     if (!CacheIsACache(x, drv = drv, conn = conn)) {
-      return(invisible(.emptyCacheTable))
+      return(.emptyCacheTable)
     }
     # }
 
@@ -202,8 +202,9 @@ setMethod(
       createCache(x, drv = drv, force = TRUE)
       # }
       if (isTRUE(getOption("reproducible.useMemoise"))) {
-        if (exists(x, envir = .pkgEnv)) {
-          rm(list = x, envir = .pkgEnv)
+        objsInMemEnv <- ls(memoiseEnv(x))
+        if (length(objsInMemEnv)) {
+          rm(list = objsInMemEnv, envir = memoiseEnv(x))
         }
       }
       # memoise::forget(.loadFromLocalRepoMem)
@@ -217,7 +218,34 @@ setMethod(
     }
 
     if (NROW(objsDT)) {
-      filesToRemove <- objsDT[grepl(pattern = "cacheRaster", tagKey)][[.cacheTableTagColName()]]
+      filesToRemove1 <- objsDT[grepl(pattern = "cacheRaster", tagKey)][[.cacheTableTagColName()]]
+      filesToRemove2 <- objsDT[grepl(pattern = "origFilename|filesToLoad|filenamesInCache", tagKey)][[.cacheTableTagColName()]]
+      filesToRemove2 <- normPath(file.path(CacheStorageDir(x), basename(filesToRemove2)))
+      filesToRemove3 <- dir(CacheStorageDir(x), full.names = TRUE)
+
+      # Way faster to gsub for the cacheId, rather than greps
+      cacheIdsOfTheseFilenames <- gsub("^.*/([0-9a-zA-Z]+)\\..*$", "\\1", filesToRemove3)
+      cacheIdsToRm <- unique(objsDT[["cacheId"]])
+      indicesToRm <- which(cacheIdsOfTheseFilenames %in% cacheIdsToRm)
+      filesToRemove4 <- filesToRemove3[indicesToRm]
+
+      # grep can only handle so many -- do in groups
+      # filesToRemove3 <- grep(paste(cacheIdsToRm, collapse = "|"), filesToRemove3, value = TRUE)
+      # maxNumForGrep <- 20
+      # sequen <- seq(cacheIdsToRm)
+      # if (length(cacheIdsToRm) > maxNumForGrep) {
+      #   groups <- cut(sequen, breaks = ceiling(length(cacheIdsToRm) / maxNumForGrep))
+      #   groups <- split(sequen, groups)
+      # } else {
+      #   groups <- list(sequen)
+      # }
+      #
+      # filesToRemove4 <- lapply(groups, function(g) {
+      #   cis <- cacheIdsToRm[sequen[g]] |> unlist()
+      #   grep(paste(cis, collapse = "|"), filesToRemove3, value = TRUE)
+      # }) |> unlist() |> unname()
+
+      filesToRemove <- unique(c(filesToRemove1, filesToRemove2, filesToRemove4))
       # filebackedInRepo <- objsDT[grepl(pattern = "fromDisk", tagKey) &
       #                           grepl(pattern = "TRUE", get(.cacheTableTagColName()))]
       #
@@ -234,8 +262,10 @@ setMethod(
         filesToRemove <- unlist(filesToRemove)
         if (isInteractive()) {
           dirLs <- dir(unique(dirname(filesToRemove)), full.names = TRUE)
-          dirLs <- unlist(lapply(basename(filesToRemove), grep, dirLs, value = TRUE))
-          cacheSize <- sum(cacheSize, file.size(dirLs))
+          filesToRemove <- dirLs[which(basename(dirLs)  %in% basename(filesToRemove))]
+          # dirLs <- unlist(lapply(basename(filesToRemove), grep, dirLs, value = TRUE))
+          # filesToRemove <- unique(c(filesToRemove, dirLs))
+          cacheSize <- sum(file.size(filesToRemove))
         }
         # }
       }
@@ -245,7 +275,8 @@ setMethod(
         formattedCacheSize <- format(cacheSize, "auto")
         if (isTRUE(ask)) {
           messageQuestion(
-            "Your size of your selected objects is ", formattedCacheSize, ".\n",
+            "Your size of your selected objects (including file-backed objects) is ",
+            formattedCacheSize, ".\n",
             " Are you sure you would like to delete it all? Y or N"
           )
           rl <- readline()
@@ -270,17 +301,14 @@ setMethod(
           })
         }
       }
-      rmFromCache(x, objToGet, conn = conn, drv = drv) # many = TRUE)
+      rmFromCache(x, objToGet, conn = conn, drv = drv, verbose = verbose) # many = TRUE)
       if (isTRUE(getOption("reproducible.useMemoise"))) {
-        if (exists(x, envir = .pkgEnv)) {
-          suppressWarnings(rm(list = objToGet, envir = .pkgEnv[[x]]))
+        exist <- vapply(objToGet, exists, envir = memoiseEnv(x), FUN.VALUE = logical(1))
+        if (isTRUE(any(exist))) {
+          suppressWarnings(rm(list = objToGet[exist], envir = memoiseEnv(x)))#.pkgEnv[[x]]))
         }
       }
-
-      # browser(expr = exists("rmFC"))
-      # }
     }
-    # memoise::forget(.loadFromLocalRepoMem)
     try(setindex(objsDT, NULL), silent = TRUE)
     return(invisible(objsDT))
   }
@@ -319,7 +347,7 @@ setMethod(
 cc <- function(secs, ..., verbose = getOption("reproducible.verbose")) {
   if (missing(secs)) {
     messageCache("No time provided; removing the most recent entry to the Cache",
-      verbose = verbose
+                 verbose = verbose
     )
     suppressMessages({
       theCache <- reproducible::showCache(...)
@@ -368,9 +396,11 @@ cc <- function(secs, ..., verbose = getOption("reproducible.verbose")) {
 #'
 setGeneric("showCache", function(x, userTags = character(), after = NULL, before = NULL,
                                  fun = NULL, cacheId = NULL,
+                                 # cacheSaveFormat = getOption("reproducible.cacheSaveFormat"),
                                  drv = getDrv(getOption("reproducible.drv", NULL)),
                                  conn = getOption("reproducible.conn", NULL),
-                                 verbose = getOption("reproducible.verbose"), ...) {
+                                 verbose = getOption("reproducible.verbose"),
+                                 ...) {
   standardGeneric("showCache")
 })
 
@@ -379,7 +409,8 @@ setGeneric("showCache", function(x, userTags = character(), after = NULL, before
 setMethod(
   "showCache",
   definition = function(x, userTags, after = NULL, before = NULL, fun = NULL,
-                        cacheId = NULL, drv, conn, ...) {
+                        cacheId = NULL, # cacheSaveFormat = getOption("reproducible.cacheSaveFormat"),
+                        drv, conn, ...) {
     # browser(expr = exists("rrrr"))
     if (missing(x)) {
       messageCache("x not specified; using ", getOption("reproducible.cachePath")[1], verbose = verbose)
@@ -410,7 +441,7 @@ setMethod(
     if (.onLinux) {
       if (exists("futureEnv", envir = .reproEnv)) {
         hasFuture <- .requireNamespace("future",
-          messageStart = "To use reproducible.futurePlan, "
+                                       messageStart = "To use reproducible.futurePlan, "
         )
         if (hasFuture) {
           checkFutures(verbose)
@@ -419,30 +450,115 @@ setMethod(
     }
 
     if (!useDBI()) {
-      if (!is.null(cacheId)) {
-        objsDT <- rbindlist(lapply(cacheId, showCacheFast, cachePath = x))
-      } else {
-        objsDT <- rbindlist(lapply(
-          dir(CacheStorageDir(x),
-              pattern = CacheDBFileSingleExt(),
-              full.names = TRUE
-          ),
-          loadFile
-        ))
+      pkgEnv <- memoiseEnv(cachePath = x)
+      if (!exists("shownCache", envir = pkgEnv))
+        pkgEnv[["shownCache"]] <- new.env()
+      if (!exists(x, envir = pkgEnv[["shownCache"]]))
+        pkgEnv[["shownCache"]][[x]] <- new.env()
+      scEnv <- pkgEnv[["shownCache"]][[x]]
+      # periodically, a cache entry is corrupt; this while, tryCatch will remove the corrupt file and restart
+      objsDT <- list()
+      while(is(objsDT, "list")) {
+        # filOutside <- character()
+        objsDT <- tryCatch(
+          if (!is.null(cacheId)) {
+            objsDT <- rbindlist(fill = TRUE, lapply(cacheId, function(fil) {
+              # filOutside <<- fil
+              showCacheFast(fil, cachePath = x, # cacheSaveFormat = cacheSaveFormat,
+                            drv = drv, conn = conn)
+            }))
+          } else {
+            dd <- dir(CacheStorageDir(x),
+                      pattern = paste(CacheDBFileSingleExt(cacheSaveFormat = .cacheSaveFormats), collapse = "|"),
+                      full.names = TRUE
+            )
+            lapplyFun <- lapply
+            curFileInfo <- file.info(dd) |> setDT(keep.rownames = "filename")
+            if (is.null(scEnv$FileInfo)) {
+              newOnes <- curFileInfo
+            } else {
+              newOnes <- curFileInfo[!scEnv$FileInfo, on = colnames(curFileInfo)]
+              removeOnes <- scEnv$FileInfo[!curFileInfo, on = colnames(curFileInfo)]
+              if (NROW(removeOnes)) {
+                scEnv$FileInfo <- scEnv$FileInfo[!removeOnes, on = colnames(curFileInfo)]
+                cis <- filePathSansExt(filePathSansExt(basename(removeOnes$filename)))
+                scEnv$sc <- scEnv$sc[!cacheId %in% cis]
+              }
+            }
+            dd <- newOnes[["filename"]]
+            scEnv$FileInfo <- curFileInfo
+
+            keepDoing <- TRUE
+            while(keepDoing) {
+              ret <- tryCatch(rbindlist(fill = TRUE, lapplyFun(dd, function(fil) {
+                out <- try(loadFile(fil), silent = TRUE)#, cacheSaveFormat = cacheSaveFormat))
+                if (is(out, "try-error")) {
+                  cacheId <- gsub(paste0(CacheDBFileSingleExt()), "",
+                                  basename(fil))
+
+                  fileEx <- fileExt(fil)
+                  fileExs <- setdiff(.cacheSaveFormats, fileEx)
+                  for (fe in fileExs) {
+                    out <- try(loadFile(fil, format = fe), silent = TRUE)
+                    if (!is(out, "try-error")) {
+                      if (identical(getOption("reproducible.cacheSaveFormat"), .qsFormat))
+                        optForUndo <- options("reproducible.qsFormat" = .qsFormat)
+                      on.exit(options(optForUndo), add = TRUE)
+                      saveFilesInCacheFolder(out, fts = fil, cachePath = x,
+                                             cacheId = cacheId)
+
+                      return(out)
+                    }
+                  }
+                  filesToRm <- dir(dirname(fil), pattern = cacheId, full.names = TRUE)
+                  messageCache("The database file was corrupt; deleting Cache entry for ", cacheId,
+                               verbose = getOption("reproducible.verbose"))
+                  unlink(filesToRm)
+                }
+                out
+
+              })), error = function(err) {
+                if (any(grepl("Item .+ is not a", err$message))) {
+                  toDel <- gsub("Item ([[:digit:]]+) of.+", "\\1", err$message) |> as.numeric()
+                  unlink(dd[toDel])
+                  dd <- dd[-toDel]
+                }
+                next
+              })
+              if (is(ret, "try-error"))
+                browser()
+              keepDoing <- FALSE
+            }
+
+            if (!is.null(scEnv$sc)) {
+              ret <- rbindlist(list(scEnv$sc, ret))
+            }
+            scEnv$sc <- ret
+            ret
+
+          }# , error = function(e) {
+          #   cacheId <- gsub(paste0(CacheDBFileSingleExt(), "|", cacheSaveFormat), "",
+          #                   basename(file))
+          #   filesToRm <- dir(dirname(file), pattern = cacheId, full.names = TRUE)
+          #   messageCache("The database file was corrupt; deleting Cache entry for ", cacheId,
+          #                   verbose = getOption("reproducible.verbose"))
+          #   unlink(filesToRm)
+          # }
+        )
       }
       if (NROW(objsDT) == 0) {
-        return(invisible(.emptyCacheTable))
+        return(.emptyCacheTable)
       }
     } else {
       if (is.null(conn)) {
         conn <- dbConnectAll(drv, cachePath = x, create = FALSE)
         if (is.null(conn)) {
-          return(invisible(.emptyCacheTable))
+          return(.emptyCacheTable)
         }
         on.exit(DBI::dbDisconnect(conn), add = TRUE)
       }
       if (!CacheIsACache(x, drv = drv, conn = conn)) {
-        return(invisible(.emptyCacheTable))
+        return(.emptyCacheTable)
       }
 
       dbTabNam <- CacheDBTableName(x, drv = drv)
@@ -474,6 +590,7 @@ setMethod(
 
     dots <- dots[!names(dots) %in% sortedOrRegexp]
     if (length(dots)) {
+      names(dots) <- gsub("^Function$", "function", names(dots)) # in case user uses Function instead of "function"
       Map(nam = names(dots), val = dots, function(nam, val) {
         objsDT <<- objsDT[objsDT[tagKey %in% nam & tagValue %in% val, ..onCol], on = onCol]
       })
@@ -486,7 +603,6 @@ setMethod(
     # }
 
     if (NROW(objsDT) > 0) {
-      # if (useDBI()) {
       if (!afterNA || !beforeNA) {
         objsDT3 <- objsDT[tagKey == "accessed"]
         if (!beforeNA) {
@@ -495,17 +611,16 @@ setMethod(
         if (!afterNA) {
           objsDT3 <- objsDT3[(tagValue >= after)]
         }
-        # objsDT3 <- objsDT3[!duplicated(cacheId)]
-        # browser(expr = exists("zzzz"))
-        # objsDT <- objsDT[cacheId %in% objsDT3$cacheId]
         objsDT <- objsDT[objsDT[[.cacheTableHashColName()]] %in%
-          unique(objsDT3[[.cacheTableHashColName()]])] # faster than data.table join
+                           unique(objsDT3[[.cacheTableHashColName()]])] # faster than data.table join
       }
-      # }
       if (length(userTags) > 0) {
         if (isTRUE(list(...)$regexp) | is.null(list(...)$regexp)) {
           objsDTs <- list()
           for (ut in userTags) {
+            if (grepl(":", ut)) {
+              ut <- paste(strsplit(ut, ":")[[1]], collapse = "|")
+            }
             objsDT2 <- objsDT[
               grepl(get(.cacheTableTagColName()), pattern = ut) |
                 grepl(tagKey, pattern = ut) |
@@ -532,8 +647,8 @@ setMethod(
       }
     }
     .message$CacheSize(x,
-      artifacts = unique(objsDT[[.cacheTableHashColName()]]),
-      cacheTable = objsDT, verbose = verbose
+                       artifacts = unique(objsDT[[.cacheTableHashColName()]]),
+                       cacheTable = objsDT, verbose = verbose
     )
     return(objsDT)
   }
@@ -560,17 +675,21 @@ setMethod(
       messageCache("x not specified; using ", getOption("reproducible.cachePath")[1], verbose = verbose)
       x <- getOption("reproducible.cachePath")[1]
     }
-    args <- append(list(x = x, after = after, before = before, userTags = userTags), list(...))
+    args <- append(list(x = x, after = after, before = before, userTags = userTags),
+                   modifyList(list(...), list(verbose = FALSE)))
 
     objsDTAll <- suppressMessages(showCache(x, verbose = FALSE, sorted = FALSE))
     objsDT <- do.call(showCache, args = args)
     keep <- unique(objsDT[[.cacheTableHashColName()]])
+
     eliminate <- unique(objsDTAll[[.cacheTableHashColName()]][
       !(objsDTAll[[.cacheTableHashColName()]] %in% keep)
     ])
 
     if (length(eliminate)) {
-      clearCache(x, eliminate, verbose = FALSE, regexp = FALSE, ask = ask)
+      clearCache(x, cacheId = eliminate, verbose = FALSE, regexp = FALSE, ask = ask)
+    } else {
+      messageCache("Nothing to remove; keeping all")
     }
     return(objsDT)
   }
@@ -615,6 +734,7 @@ setMethod(
   "mergeCache",
   definition = function(cacheTo, cacheFrom, drvTo, drvFrom, connTo, connFrom,
                         verbose = getOption("reproducible.verbose")) {
+
     if (useDBI()) {
       if (is.null(connTo)) {
         connTo <- dbConnectAll(drvTo, cachePath = cacheTo)
@@ -637,6 +757,7 @@ setMethod(
     artifacts <- unique(cacheFromList[[.cacheTableHashColName()]])
     objectList <- lapply(artifacts, function(artifact) {
       # browser(expr = exists("gggg"))
+
       if (!(artifact %in% cacheToList[[.cacheTableHashColName()]])) {
         outputToSave <- # if (useDBI()) {
           try(loadFromCache(
@@ -650,12 +771,12 @@ setMethod(
 
         ## Save it
         userTags <- cacheFromList[artifact, on = .cacheTableHashColName()][
-          !tagKey %in% c("format", "name", "date", "cacheId"), list(tagKey, tagValue)
+          !tagKey %in% c("format", "name", "date"), list(tagKey, tagValue)
         ]
         outputToSave <- .wrap(outputToSave, cachePath = cacheTo, drv = drvTo, conn = connTo)
         output <- saveToCache(cacheTo,
-          userTags = userTags, obj = outputToSave, cacheId = artifact,
-          drv = drvTo, conn = connTo
+                              userTags = userTags, obj = outputToSave, cacheId = artifact,
+                              drv = drvTo, conn = connTo
         ) # nolint
         messageCache(artifact, " copied", verbose = verbose)
         outputToSave
@@ -691,7 +812,7 @@ checkFutures <- function(verbose = getOption("reproducible.verbose")) {
         Sys.sleep(0.001)
         if (count > 1e3) {
           messageCache("Future is not resolved after 1 second of waiting. Allowing to proceed.",
-            verbose = verbose
+                       verbose = verbose
           )
           break
         }
@@ -731,8 +852,8 @@ useDBI <- function(set = NULL, verbose = getOption("reproducible.verbose"), defa
 
   if (isFALSE(canSwitch)) {
     messageColoured("User has requested to use DBI as the backend, but DBI and/or RSQLite not ",
-      "installed.",
-      verboseLevel = 1, verbose = verbose
+                    "installed.",
+                    verboseLevel = 1, verbose = verbose
     )
   }
   if (!is.null(set)) {
@@ -741,7 +862,9 @@ useDBI <- function(set = NULL, verbose = getOption("reproducible.verbose"), defa
     } else {
       "Using non-DBI backend."
     }
-    messageColoured(messSet, verboseLevel = 0, verbose = verbose)
+    if (verbose > -1) {
+      messageColoured(messSet, verboseLevel = 0, verbose = verbose)
+    }
   }
 
   ud
@@ -781,13 +904,25 @@ isTRUEorForce <- function(cond) {
   isTRUE(cond) || identical(cond, "force")
 }
 
-showCacheFast <- function(cacheId, cachePath = getOption("reproducible.cachePath")) {
-  fileexists <- dir(CacheStorageDir(cachePath), full.names = TRUE,
-                    pattern = paste0(cacheId, "\\.dbFile"))
-  if (length(fileexists)) {
-    sc <- loadFile(fileexists)
-  } else {
-    sc <- showCache(userTags = cacheId, verbose = FALSE)[cacheId %in% cacheId]
+showCacheFast <- function(cacheId, cachePath = getOption("reproducible.cachePath"),
+                          dtFile, strict = TRUE, # cacheSaveFormat = getOption("reproducible.cacheSaveFormat"),
+                          drv, conn) {
+
+  if (missing(dtFile)) {
+    # dtFile <- CacheDBFileSingle(cachePath, cacheId, cacheSaveFormat = "check")
+    dtFile <- CacheDBFileSingle(cachePath, cacheId, cacheSaveFormat = "check")
+    # dtFile <- dir(CacheStorageDir(cachePath), full.names = TRUE,
+    #               pattern = paste0(cacheId, "\\", suffixMultipleDBFiles()))
+  }
+  fe <- file.exists(dtFile)
+  sc <- NULL
+  if (fe || isFALSE(strict)) {
+    dtFile <- if (any(fe)) dtFile[fe][1] else character()
+    if (length(dtFile)) {
+      sc <- loadFile(dtFile) # , cacheSaveFormat = cacheSaveFormat)
+    } else {
+      sc <- showCache(cachePath, userTags = cacheId, drv = drv, conn = conn, verbose = FALSE)[cacheId %in% cacheId]
+    }
   }
   sc[]
 }
