@@ -19,6 +19,7 @@
   if (any(toset)) options(opts.reproducible[toset])
   .pkgEnv$SysInfo <- Sys.info() # record once at loading; repeatedly calling Sys.info is a waste
 
+  .pkgEnv$runningOnMac <- isMac()
   invisible()
 }
 
@@ -29,11 +30,7 @@
       "Using reproducible version ",
       utils::packageVersion("reproducible"), ".",
       # "\n  'reproducible' has changed the default database backend.", # Not true yet
-      " As of reproducible >=2.1.2, character vectors (including ",
-      "inside data.frames)\n  will not be treated as file paths by `Cache`; ",
-      "convert to 'Path' or `fs_path` first if needed.\n",
-      "  Set `options(reproducible.testCharacterAsFile = TRUE)` for old behaviour;\n",
-      "  See ?reproducibleOptions for details.")
+      " See ?reproducibleOptions for many possible settings.")
   }
 }
 
