@@ -6,37 +6,33 @@ test_that("test Cache(useCloud=TRUE, ...)", {
     c("googledrive", "terra"),
     tmpFileExt = c(".tif", ".grd"),
     needGoogleDriveAuth = TRUE,
-    opts = list(
-      "reproducible.cachePath" = file.path(tempdir(), rndstr(1, 7)),
-      "reproducible.ask" = FALSE
-    )
+  )
+
+  ## service accounts cannot upload to standard drive folders (no quota)
+  skip_if_service_account_releaseVer_NotLinux()
+
+  withr::local_options(
+    reproducible.cachePath = file.path(tempdir(), rndstr(1, 7)),
+    reproducible.ask = FALSE,
+    reproducible.useMemoise = FALSE
   )
 
   clearCache(x = tmpCache)
+  googleSetupForUseCloud(cloudFolderID, tmpdir, tmpCache)
+
   testsForPkgs <- "testsForPkgs"
-  if (isTRUE(tryCatch(googledrive::drive_ls(testsForPkgs), error = function(e) TRUE))) {
-    testsForPkgsDir <- retry(quote(googledrive::drive_mkdir(name = testsForPkgs)))
-  }
+  tryCatch(googledrive::drive_ls(testsForPkgs), error = function(x)
+    googledrive::drive_mkdir(name = testsForPkgs))
   newDir <- retry(quote(googledrive::drive_mkdir(name = rndstr(1, 6), path = testsForPkgs)))
   cloudFolderID <- newDir
-  on.exit(
-    {
-      retry(quote(googledrive::drive_rm(cloudFolderID)))
-    },
-    add = TRUE
-  )
 
-  #######################################
   # local absent, cloud absent
-  #######################################
   mess1 <- capture_messages({
     a1 <- Cache(rnorm, 1, cloudFolderID = cloudFolderID, cachePath = tmpCache, useCloud = TRUE)
   })
   expect_true(any(grepl("Uploading", mess1)))
 
-  #######################################
   # local present, cloud present
-  #######################################
   mess2 <- capture_messages({
     a1 <- Cache(rnorm, 1, cloudFolderID = cloudFolderID, cachePath = tmpCache, useCloud = TRUE)
   })
@@ -45,22 +41,22 @@ test_that("test Cache(useCloud=TRUE, ...)", {
   expect_false(all(grepl("uploaded", ignore.case = TRUE, mess2)))
   expect_false(all(grepl("download", mess2)))
 
-  #######################################
   # local absent, cloud present
-  #######################################
-  # kkkk <<- 1
-
   clearCache(userTags = .robustDigest(1), x = tmpCache, useCloud = FALSE)
   mess3 <- capture_messages({
     a1 <- Cache(rnorm, 1, cloudFolderID = cloudFolderID, cachePath = tmpCache, useCloud = TRUE)
   })
-  expect_false(any(grepl(.message$LoadedCacheResult(), mess3)))
+
+  # it is actually both loaded & saved locally; so should be loadedCachedResult and saved
+  if (!useDBI()) {
+    expect_true(any(grepl(.message$LoadedCacheResult(), mess3)))
+  } else {
+    expect_false(any(grepl(.message$LoadedCacheResult(), mess3)))
+  }
   expect_false(any(grepl("Uploaded", mess3)))
   expect_true(any(grepl("Downloading", mess3)))
 
-  #######################################
   # local present, cloud absent
-  #######################################
   clearCache(x = tmpCache, useCloud = TRUE, cloudFolderID = cloudFolderID)
   a1 <- Cache(rnorm, 2, cloudFolderID = cloudFolderID, cachePath = tmpCache)
   mess4 <- capture_messages({
@@ -71,38 +67,44 @@ test_that("test Cache(useCloud=TRUE, ...)", {
   expect_true(any(grepl("Uploading", mess4)))
   expect_false(any(grepl("Download", mess4)))
 
-  #######################################
   # cloudFolderID missing
-  #######################################
   reproducible::clearCache(x = tmpCache, useCloud = TRUE, cloudFolderID = cloudFolderID)
 
-  opts <- options("reproducible.cloudFolderID" = NULL)
-
+  withr::local_options("reproducible.cloudFolderID" = NULL)
+  # on.exit(try(googledrive::drive_rm(cloudFolderFromCacheRepo(tmpdir))), add = TRUE)
+  # Try two different cloud folders -- based on tmpdir and tmpCache
   warn5 <- capture_warnings({
     mess5 <- capture_messages({
       a2 <- Cache(rnorm, 3, cachePath = tmpdir, useCloud = TRUE)
     })
   })
+  options("reproducible.cloudFolderID" = NULL)
 
   expect_true(any(grepl("Uploading", mess5)))
   expect_false(any(grepl("Download", mess5)))
 
+
+  # on.exit(try(googledrive::drive_rm(cloudFolderFromCacheRepo(tmpCache))), add = TRUE)
   warn6 <- capture_warnings({
     mess6 <- capture_messages({
       a2 <- Cache(rnorm, 3, cachePath = tmpCache, useCloud = TRUE)
     })
   })
 
-  # expect_false(any(grepl("Folder created", mess6)))
   expect_true(any(grepl("Uploading", mess6)))
   expect_false(any(grepl("Download", mess6)))
   expect_false(any(grepl(.message$LoadedCacheResult(), mess6)))
   expect_true(isTRUE(all.equal(length(warn6), 0)))
 
-  ########
-  try(googledrive::drive_rm(newDir), silent = TRUE) # clear the original one
-  cloudFolderID <- getOption("reproducible.cloudFolderID")
-  clearCache(x = tmpCache, useCloud = TRUE) # , cloudFolderID = cloudFolderID)
+  # Clear all
+  try(drive_rm(drive_ls(cloudFolderFromCacheRepo(tmpCache))), silent = TRUE)
+
+  # will use getOption("reproducible.cloudFolderID") b/c not specified, which is not cloudFolderFromCacheRepo(tmpCache)
+  # clearCache(x = tmpCache, useCloud = TRUE)
+  # Switch to tmpCache only
+  withr::local_options(reproducible.cloudFolderID = tmpCache)
+  cloudFolderID <- getOption("reproducible.cloudFolderID") # currently based on tmpCache
+
   # Add 3 things to cloud and local -- then clear them all
   for (i in 1:3) {
     a1 <- Cache(rnorm, i, cloudFolderID = cloudFolderID, cachePath = tmpCache, useCloud = TRUE)
@@ -146,18 +148,22 @@ test_that("test Cache(useCloud=TRUE, ...) with raster-backed objs -- tif and grd
   skip_on_ci()
   testInit(c("googledrive", "terra"),
     needGoogleDriveAuth = TRUE,
-    opts = list("reproducible.ask" = FALSE)
+    opts = list(reproducible.ask = FALSE)
   )
 
-  opts <- options("reproducible.cachePath" = tmpdir)
+  ## service accounts cannot upload to standard drive folders (no quota)
+  skip_if_service_account_releaseVer_NotLinux()
 
-  on.exit(
-    {
-      retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
-      options(opts)
-    },
-    add = TRUE
-  )
+  googleSetupForUseCloud(cloudFolderID, tmpdir, tmpCache)
+
+  withr::local_options(reproducible.cachePath = tmpdir)
+
+  # on.exit(
+  #   {
+  #     retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
+  #   },
+  #   add = TRUE
+  # )
   clearCache(x = tmpCache)
   clearCache(x = tmpdir)
   newDir <- retry(quote(googledrive::drive_mkdir(name = basename2(tmpdir), path = "testsForPkgs")))
@@ -173,7 +179,7 @@ test_that("test Cache(useCloud=TRUE, ...) with raster-backed objs -- tif and grd
   newDir <- retry(quote(googledrive::drive_mkdir(name = rndstr(1, 6), path = "testsForPkgs")))
   cloudFolderID <- newDir
 
-  # the 3 raster files include the .grd, .gri, and .grd.aux.xml
+  ## the 3 raster files include the .grd, .gri, and .grd.aux.xml
   testRasterInCloud(".grd",
     cloudFolderID = cloudFolderID, numRasterFiles = 3, tmpdir = tmpdir,
     type = "Raster"
@@ -185,18 +191,14 @@ test_that("test Cache(useCloud=TRUE, ...) with raster-backed objs -- stack", {
   skip_on_ci()
   testInit(c("googledrive", "terra"),
     needGoogleDriveAuth = TRUE,
-    opts = list("reproducible.ask" = FALSE)
+    opts = list(reproducible.ask = FALSE)
   )
 
-  on.exit(
-    {
-      retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
-      options(opts)
-    },
-    add = TRUE
-  )
-  opts <- options("reproducible.cachePath" = tmpdir)
-  on.exit(options(opts), add = TRUE)
+  ## service accounts cannot upload to standard drive folders (no quota)
+  skip_if_service_account_releaseVer_NotLinux()
+
+  googleSetupForUseCloud(cloudFolderID, tmpdir, tmpCache)
+  withr::local_options(reproducible.cachePath = tmpdir)
   clearCache(x = tmpCache)
   clearCache(x = tmpdir)
   newDir <- retry(quote(googledrive::drive_mkdir(name = basename2(tmpdir), path = "testsForPkgs")))
@@ -213,17 +215,14 @@ test_that("test Cache(useCloud=TRUE, ...) with raster-backed objs -- brick", {
   skip_on_ci()
   testInit(c("googledrive", "terra"),
     needGoogleDriveAuth = TRUE,
-    opts = list("reproducible.ask" = FALSE)
+    opts = list(reproducible.ask = FALSE)
   )
 
-  opts <- options("reproducible.cachePath" = tmpdir)
-  on.exit(
-    {
-      retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
-      options(opts)
-    },
-    add = TRUE
-  )
+  ## service accounts cannot upload to standard drive folders (no quota)
+  skip_if_service_account_releaseVer_NotLinux()
+
+  googleSetupForUseCloud(cloudFolderID, tmpdir, tmpCache)
+  withr::local_options(reproducible.cachePath = tmpdir)
   clearCache(x = tmpCache)
   clearCache(x = tmpdir)
   newDir <- retry(quote(googledrive::drive_mkdir(name = tempdir2(), path = "testsForPkgs")))
@@ -239,22 +238,20 @@ test_that("prepInputs works with team drives", {
   skip_on_cran()
   skip_on_ci()
 
-  testInit(
-    needGoogleDriveAuth = TRUE,
-    "googledrive",
-    opts = list(
-      "reproducible.cachePath" = file.path(tempdir(), rndstr(1, 7)),
-      "reproducible.ask" = FALSE
-    )
+  testInit(needGoogleDriveAuth = TRUE, "googledrive")
+  withr::local_options(
+    reproducible.cachePath = file.path(tempdir(), rndstr(1, 7)),
+    reproducible.ask = FALSE
   )
 
+  googleSetupForUseCloud(cloudFolderID, tmpdir, tmpCache)
+
   # zipUrl <- "https://drive.google.com/file/d/1zRX2c55ebJbQtjijCErEfGxhsa7Ieph2" # Orig
   zipUrl <- "https://drive.google.com/file/d/1JpdvM8QiyCyNyQAvSaFU0rAY-1I3mcbp"
 
   # This will fail if it is hit too many times -- we don't want the test to report
   #  fail because of this
-  opts <- options("reproducible.interactiveOnDownloadFail" = FALSE)
-  on.exit(options(opts), add = TRUE)
+  withr::local_options("reproducible.interactiveOnDownloadFail" = FALSE)
   if (packageVersion("googledrive") < "2.0.0") {
     wb <- prepInputs(
       targetFile = "WB_BCR.shp", destinationPath = tmpdir, url = zipUrl,
